All of lore.kernel.org
 help / color / mirror / Atom feed
From: zkabelac@sourceware.org <zkabelac@sourceware.org>
To: lvm-devel@redhat.com
Subject: LVM2/test lvm-utils.sh
Date: 26 Mar 2010 13:21:28 -0000	[thread overview]
Message-ID: <20100326132128.1572.qmail@sourceware.org> (raw)

CVSROOT:	/cvs/lvm2
Module name:	LVM2
Changes by:	zkabelac at sourceware.org	2010-03-26 13:21:28

Modified files:
	test           : lvm-utils.sh 

Log message:
	Updates .so links for plugins

Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/test/lvm-utils.sh.diff?cvsroot=lvm2&r1=1.22&r2=1.23

--- LVM2/test/lvm-utils.sh	2010/03/25 12:17:10	1.22
+++ LVM2/test/lvm-utils.sh	2010/03/26 13:21:28	1.23
@@ -196,10 +196,10 @@
   for i in 0 1 2 3 4 5 6 7; do
     mknod $G_root_/dev/loop$i b 7 $i
   done
-  for i in $abs_top_builddir/dmeventd/mirror/*.so $abs_top_builddir/dmeventd/snapshot/*.so
+  for i in $abs_top_builddir/daemons/dmeventd/plugins/*/*.so
   do
     # NOTE: This check is necessary because the loop above will give us the value
     # "$abs_top_builddir/dmeventd/mirror/*.so" if no files ending in 'so' exist.
     # This is the best way I could quickly determine to skip over this bogus value.
     if [ -f $i ]; then
       echo Setting up symlink from $i to $G_root_/lib
@@ -196,10 +196,10 @@
   do
     # NOTE: This check is necessary because the loop above will give us the value
-    # "$abs_top_builddir/dmeventd/mirror/*.so" if no files ending in 'so' exist.
+    # "$abs_top_builddir/daemons/dmeventd/plugins/*/*.so" if no files ending in 'so' exist.
     # This is the best way I could quickly determine to skip over this bogus value.
     if [ -f $i ]; then



             reply	other threads:[~2010-03-26 13:21 UTC|newest]

Thread overview: 9+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2010-03-26 13:21 zkabelac [this message]
  -- strict thread matches above, loose matches on Subject: below --
2010-03-25 12:17 LVM2/test lvm-utils.sh agk
2010-03-25 11:57 agk
2009-01-10 12:19 mornfall
2008-08-21 14:33 wysochanski
2008-06-25 16:51 wysochanski
2008-06-06 13:48 meyering
2008-04-23 13:02 wysochanski
2008-03-28 18:02 wysochanski

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20100326132128.1572.qmail@sourceware.org \
    --to=zkabelac@sourceware.org \
    --cc=lvm-devel@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.